searchNodes=[{"ref":"Modular.html","title":"Modular","module":"Modular","type":"module","doc":"Apply modular programming principles and patterns to build better Elixir apps."},{"ref":"Modular.AreaAccess.html","title":"Modular.AreaAccess","module":"Modular.AreaAccess","type":"module","doc":"Allows to declare external deps and optionally resolve them to mocks. Usage Define area behaviours and implementations: defmodule MyApp.First do @callback some() :: :ok end defmodule MyApp.Second do @callback other() :: :ok end defmodule MyApp.First.Impl do @behaviour MyApp.First def some do :ok end end defmodule MyApp.Second.Impl do @behaviour MyApp.Second def other do :ok end end Declare dependencies and call other areas: defmodule MyApp.First.Impl do @behaviour MyApp.First use Modular.AreaAccess, [ MyApp.Second ] def some do impl(MyApp.Second).other() end end Mocking Enable mocking and configure areas that are viable for it in config/test.exs: config :modular, area_mocking_enabled: true, areas: [ MyApp.First, MyApp.Second ] Setup mocks for Mox intest/suport/mocks.ex (follow Mox docs on including the test/support directory in compile paths): Modular.AreaAccess.define_mocks() Then allow usage of any areas from test cases and stub them back to real implementations: defmodule MyCase do use ExUnit.CaseTemplate using do quote do use Modular.AreaAccess, :all end end setup do Modular.AreaAccess.install_stubs() :ok end end Write tests as normal and mock with custom expectations when needed: defmodule MyTest do use MyCase test &quot;normal case&quot; do assert :ok = impl(MyApp.First).some() end test &quot;mocked case&quot; do Mox.expect(impl(MyApp.Second), :other, fn -&gt; :mocked end) assert :mocked = impl(MyApp.First).some() end end"},{"ref":"Modular.AreaAccess.html#define_mocks/0","title":"Modular.AreaAccess.define_mocks/0","module":"Modular.AreaAccess","type":"function","doc":""},{"ref":"Modular.AreaAccess.html#impl/1","title":"Modular.AreaAccess.impl/1","module":"Modular.AreaAccess","type":"macro","doc":""},{"ref":"Modular.AreaAccess.html#install_stubs/0","title":"Modular.AreaAccess.install_stubs/0","module":"Modular.AreaAccess","type":"function","doc":""},{"ref":"Modular.Delegate.html","title":"Modular.Delegate","module":"Modular.Delegate","type":"module","doc":"Defines thin contracts with convention-driven call delegation to internal implementations. Example iex&gt; defmodule Invoicing.CreateUser do iex&gt; def call(name), do: {:ok, name} iex&gt; end iex&gt; iex&gt; defmodule Invoicing do iex&gt; use Modular.Delegate iex&gt; iex&gt; defcall create_user(name) iex&gt; end iex&gt; iex&gt; Invoicing.create_user(&quot;Mike&quot;) {:ok, &quot;Mike&quot;}"},{"ref":"Modular.Delegate.html#defcall/1","title":"Modular.Delegate.defcall/1","module":"Modular.Delegate","type":"macro","doc":""},{"ref":"Modular.Mutability.html","title":"Modular.Mutability","module":"Modular.Mutability","type":"module","doc":"Provides command/query annotations for functions within area contracts. Examples defmodule Invoicing do use Modular.Mutability @command true def create_user, do: :error @query true def get_users, do: [] end"},{"ref":"Modular.Owner.html","title":"Modular.Owner","module":"Modular.Owner","type":"module","doc":"Provides ownership annotations for area contracts. Examples iex&gt; defmodule Invoicing do iex&gt; use Modular.Owner iex&gt; iex&gt; @owner &quot;me@example.com&quot; iex&gt; end iex&gt; iex&gt; Invoicing.__owner__() &quot;me@example.com&quot;"},{"ref":"readme.html","title":"Modular","module":"readme","type":"extras","doc":"Modular Apply modular programming principles and patterns to build better Elixir apps. Modular is a toolbox that helps Elixir developers to apply modular programming principles and patterns in their projects. It includes checks for defining and enforcing modular programming rules &amp; conventions as well as utilities for mapping the characteristics of a growing project. Modular currently offers following tools: Modular.AreaAccess - allows to declare external deps and optionally resolve them to mocks Modular.Delegate - defines thin contracts with call delegation to internal implementations Modular.Mutability - provides command/query annotations for functions within area contracts Modular.Owner - provides ownership annotations for area contracts"},{"ref":"readme.html#installation","title":"Modular - Installation","module":"readme","type":"extras","doc":"Add modular to your list of dependencies in mix.exs: def deps do [ {:modular, &quot;~&gt; 0.1&quot;} ] end"},{"ref":"changelog.html","title":"Changelog","module":"changelog","type":"extras","doc":"Changelog"},{"ref":"changelog.html#0-3-1","title":"Changelog - 0.3.1","module":"changelog","type":"extras","doc":"Fixed Modular.AreaAccess.install_stubs/0 performance (#4)"},{"ref":"changelog.html#0-3-0","title":"Changelog - 0.3.0","module":"changelog","type":"extras","doc":"Fixed Modular.AreaAccess for umbrella projects"},{"ref":"changelog.html#0-2-0","title":"Changelog - 0.2.0","module":"changelog","type":"extras","doc":"Added Modular.AreaAccess Removed all checks (moved to separate project)"}]